//
//  ViewController.swift
//  yandextest
//
//  Created by ben on 7/30/20.
//  Copyright © 2020 espiru. All rights reserved.
//

import UIKit
import IGListKit
import YandexMobileAds

class ViewController: UIViewController {

    @IBOutlet weak var collectionView: UICollectionView!
    
    private var yandexBannerView: YMAAdView? = nil
    private var yandexBannerLoaded: Bool = false
    
    lazy var adapter: ListAdapter = {
        return ListAdapter(
            updater: ListAdapterUpdater(),
            viewController: self,
            workingRangeSize: 1
        )
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        let adSize = YMAAdSize.flexibleSize(withContainerWidth: self.view.frame.width)
        self.yandexBannerView = YMAAdView(blockID: "adf-264109/1120517", adSize: adSize, delegate: self)
        
        YMAMobileAds.enableLogging()
        
        self.yandexBannerView?.loadAd()
        
        collectionView.collectionViewLayout = ListCollectionViewLayout(stickyHeaders: false, topContentInset: 0, stretchToEdge: true)
        
        adapter.collectionView = collectionView
        adapter.dataSource = self
        
        self.adapter.performUpdates(animated: true)
    }
}

// MARK: - ListAdapterDataSource
extension ViewController: ListAdapterDataSource {
  func objects(for listAdapter: ListAdapter) -> [ListDiffable] {
    var objects = [] as! [ListDiffable]

    for item in (1...10) {
        objects.append(ContentObject(content: "Content \(item)"))
    }
    
    if self.yandexBannerLoaded {
        objects.append(BannerObject(banner: self.yandexBannerView))
    }

    return objects
  }

  func listAdapter(_ listAdapter: ListAdapter, sectionControllerFor object: Any) -> ListSectionController {
    if object is BannerObject {
        return BannerSectionController()
    }
    
    return ContentSectionController()
  }

  func emptyView(for listAdapter: ListAdapter) -> UIView? {
    return nil
  }
}

extension ViewController: YMAAdViewDelegate {
    func adViewDidLoad(_ adView: YMAAdView!) {
        print("Ad loaded")

        self.yandexBannerLoaded = true

        DispatchQueue.main.async {
            self.adapter.performUpdates(animated: false)
        }
    }

    func adViewDidFailLoading(_ adView: YMAAdView!, error: Error!) {
        print("Ad failed loading. Error: \(error!)")
    }
}

